@@ -12,7 +12,7 @@ use File::Basename;
 use File::Path qw(make_path);
 use Scalar::Util qw(looks_like_number);
 
-our $VERSION = '0.17';
+our $VERSION = '0.18';
 
 # Configure YAML::XS to not quote numeric strings
 $YAML::XS::QuoteNumericStrings = 0;
@@ -1678,7 +1678,8 @@ sub _write_schema {
 
 	open my $fh, '>', $filename;
 	print $fh YAML::XS::Dump($output);
-	print $fh "\n# Run this script through fuzz-harness-generator -r\n",
+	print $fh "\n# Generated by ", ref($self), "\n",
+		"# Run this script through fuzz-harness-generator -r\n",
 		"# Input confidence: $schema->{_confidence}{input}\n",
 		"# Output confidence: $schema->{_confidence}{output}\n";
 	if($self->{_notes} && scalar(@{$self->{_notes}})) {
